<?php

/*******************************************************************************

	Author  .......  Daniel B. Hemmerich
	Contact  ......  dan@spot.org
	Home Site  ....  http://www.spot.org/
	Program  ......  SquirrelMail Plugin - Weather
	Version  ......  4.1.1

*******************************************************************************/

function squirrelmail_plugin_init_weather()
{
	global $squirrelmail_plugin_hooks;

	$squirrelmail_plugin_hooks['left_main_before']['weather'] = 'weather_show_before';
	$squirrelmail_plugin_hooks['left_main_after']['weather'] = 'weather_show_after';
	$squirrelmail_plugin_hooks['optpage_register_block']['weather'] = 'weather_optpage_register_block';

	return;
}

function weather_show_before ()
{

  if (defined('SM_PATH'))
     include_once(SM_PATH . 'plugins/weather/functions.php');
  else
     include_once('../plugins/weather/functions.php');

  weather_show_before_do();

}


function weather_show_after ()
{

  if (defined('SM_PATH'))
     include_once(SM_PATH . 'plugins/weather/functions.php');
  else
     include_once('../plugins/weather/functions.php');

  weather_show_after_do();

}

function weather_optpage_register_block ()
{

  if (defined('SM_PATH'))
     include_once(SM_PATH . 'plugins/weather/functions.php');
  else
     include_once('../plugins/weather/functions.php');

  weather_optpage_register_block_do();

}

function weather_version()
{

   return '4.1.1';

}

?>
